emlib
=====

emlib is a set of modules with miscelaneous functionality:

- maths: 
    - base conversion, euclidian distance, min. common denominator, etc.
    - combinatorics
    - number theory
    - number series
    - markov chains
    - utilities to traverse graphs
- matplotlib enhancements
- csv utilities
- iterator tools (similar to more_itertools)
- containers: RecordList (a list of named tuples)
- doctools: tools to generate documentation (for mkdocs particularly)
- etc

-----

Documentation
-------------

https://emlib.readthedocs.io


-----

Installation

.. code:: bash

    pip install emlib

